@@ -98,7 +98,7 @@ class AppAgent(StandardAgent):
                         "message": "Provision was running on this Instance. Probably a freaking race condition",
                         "state": ProvideState.ACTIVE,
                         "mode": ProvideMode.DEBUG
-                        if self.config.agent.debug
+                        if self.config.debug
                         else ProvideMode.PRODUCTION,
                     },
                     meta={
