@@ -1,9 +1,13 @@
-
 from ..log import LogDataModel
 from enum import Enum
 from pydantic.main import BaseModel
-from ....messages.types import  PROVIDE_TRANSITION
-from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
+from ....messages.types import PROVIDE_TRANSITION
+from ....messages.base import (
+    MessageDataModel,
+    MessageMetaExtensionsModel,
+    MessageMetaModel,
+    MessageModel,
+)
 from typing import List, Optional
 
 
@@ -12,6 +16,7 @@ class MetaExtensionsModel(MessageMetaExtensionsModel):
     progress: Optional[str]
     callback: Optional[str]
 
+
 class MetaModel(MessageMetaModel):
     type: str = PROVIDE_TRANSITION
     extensions: Optional[MetaExtensionsModel]
@@ -21,7 +26,7 @@ class ProvideState(str, Enum):
     # Start State
     PENDING = "PENDING"
     PROVIDING = "PROVIDING"
-    
+
     # Life States
     ACTIVE = "ACTIVE"
     INACTIVE = "INACTIVE"
@@ -38,8 +43,15 @@ class ProvideState(str, Enum):
     CANCELLED = "CANCELLED"
 
 
+class ProvideMode(str, Enum):
+    # Start State
+    DEBUG = "DEBUG"
+    PRODUCTION = "PRODUCTION"
+
+
 class ProvideTransistionData(MessageDataModel):
     state: ProvideState
+    mode: ProvideMode = ProvideMode.PRODUCTION
     message: Optional[str]
 
 
@@ -48,8 +60,9 @@ class ProvideTransitionMessage(MessageModel):
     meta: MetaModel
 
     @classmethod
-    def from_critical(cls,reference, exception, extensions={}):
-        return cls(data={
-            "message": str(exception),
-            "state": ProvideState.CRITICAL
-            }, meta={"extensions": extensions, "reference":reference})
\ No newline at end of file
+    def from_critical(cls, reference, exception, extensions={}):
+        print(reference)
+        return cls(
+            data={"message": str(exception), "state": ProvideState.CRITICAL},
+            meta={"extensions": extensions, "reference": reference},
+        )
