@@ -60,8 +60,8 @@ class Postman:
 
     async def adisconnect(self):
         await self.ward.adisconnect()
-        print("nosinsoins")
         await self.transport.adisconnect()
+        logger.info(f"Successfully disconnected Postman {self}")
 
 
     async def broadcast(self, message: MessageModel):
